package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class BasicOCSPResponse extends ASN1Encodable {
   private ResponseData tbsResponseData;
   private AlgorithmIdentifier signatureAlgorithm;
   private DERBitString signature;
   private ASN1Sequence certs;

   public BasicOCSPResponse(ResponseData tbsResponseData, AlgorithmIdentifier signatureAlgorithm, DERBitString signature, ASN1Sequence certs) {
      this.tbsResponseData = tbsResponseData;
      this.signatureAlgorithm = signatureAlgorithm;
      this.signature = signature;
      this.certs = certs;
   }

   public BasicOCSPResponse(ASN1Sequence seq) {
      this.tbsResponseData = ResponseData.getInstance(seq.getObjectAt(0));
      this.signatureAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(1));
      this.signature = (DERBitString)seq.getObjectAt(2);
      if (seq.size() > 3) {
         this.certs = ASN1Sequence.getInstance((ASN1TaggedObject)seq.getObjectAt(3), true);
      }

   }

   public static BasicOCSPResponse getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static BasicOCSPResponse getInstance(Object obj) {
      if (obj != null && !(obj instanceof BasicOCSPResponse)) {
         if (obj instanceof ASN1Sequence) {
            return new BasicOCSPResponse((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (BasicOCSPResponse)obj;
      }
   }

   public ResponseData getTbsResponseData() {
      return this.tbsResponseData;
   }

   public AlgorithmIdentifier getSignatureAlgorithm() {
      return this.signatureAlgorithm;
   }

   public DERBitString getSignature() {
      return this.signature;
   }

   public ASN1Sequence getCerts() {
      return this.certs;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.tbsResponseData);
      var1.add(this.signatureAlgorithm);
      var10001.add(this.signature);
      ASN1Sequence var3;
      if ((var3 = this.certs) != null) {
         DERTaggedObject var2;
         var2 = new DERTaggedObject.<init>(true, 0, var3);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
